
#line 3 "reader.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define yy_create_buffer rmap_create_buffer
#define yy_delete_buffer rmap_delete_buffer
#define yy_flex_debug rmap_flex_debug
#define yy_init_buffer rmap_init_buffer
#define yy_flush_buffer rmap_flush_buffer
#define yy_load_buffer_state rmap_load_buffer_state
#define yy_switch_to_buffer rmap_switch_to_buffer
#define yyin rmapin
#define yyleng rmapleng
#define yylex rmaplex
#define yylineno rmaplineno
#define yyout rmapout
#define yyrestart rmaprestart
#define yytext rmaptext
#define yywrap rmapwrap
#define yyalloc rmapalloc
#define yyrealloc rmaprealloc
#define yyfree rmapfree

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 5
#define YY_FLEX_SUBMINOR_VERSION 37
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

#if defined(__FreeBSD__)
#ifndef __STDC_LIMIT_MACROS
#define	__STDC_LIMIT_MACROS
#endif
#include <sys/cdefs.h>
#include <stdint.h>
#else
#define	__dead2
#endif

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined(__FreeBSD__) || \
    (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L)

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

#ifdef __cplusplus

/* The "const" storage-class-modifier is valid. */
#define YY_USE_CONST

#else	/* ! __cplusplus */

/* C99 requires __STDC__ to be defined as 1. */
#if defined (__STDC__)

#define YY_USE_CONST

#endif	/* defined (__STDC__) */
#endif	/* ! __cplusplus */

#ifdef YY_USE_CONST
#define yyconst const
#else
#define yyconst
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an unsigned
 * integer for use as an array index.  If the signed char is negative,
 * we want to instead treat it as an 8-bit unsigned char, hence the
 * double cast.
 */
#define YY_SC_TO_UI(c) ((unsigned int) (unsigned char) c)

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *

/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START

/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)

/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE rmaprestart(rmapin  )

#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#define YY_BUF_SIZE 16384
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern yy_size_t rmapleng;

extern FILE *rmapin, *rmapout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2

    #define YY_LESS_LINENO(n)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up rmaptext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up rmaptext again */ \
		} \
	while ( 0 )

#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	yy_size_t yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	yy_size_t yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */
    
	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via rmaprestart()), so that the user can continue scanning by
	 * just pointing rmapin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = 0; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
#define yy_current_buffer YY_CURRENT_BUFFER

/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when rmaptext is formed. */
static char yy_hold_char;
static yy_size_t yy_n_chars;		/* number of characters read into yy_ch_buf */
yy_size_t rmapleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = (char *) 0;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow rmapwrap()'s to do buffer switches
 * instead of setting up a fresh rmapin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void rmaprestart (FILE *input_file  );
void rmap_switch_to_buffer (YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE rmap_create_buffer (FILE *file,int size  );
void rmap_delete_buffer (YY_BUFFER_STATE b  );
void rmap_flush_buffer (YY_BUFFER_STATE b  );
void rmappush_buffer_state (YY_BUFFER_STATE new_buffer  );
void rmappop_buffer_state (void );

static void rmapensure_buffer_stack (void );
static void rmap_load_buffer_state (void );
static void rmap_init_buffer (YY_BUFFER_STATE b,FILE *file  );

#define YY_FLUSH_BUFFER rmap_flush_buffer(YY_CURRENT_BUFFER )

YY_BUFFER_STATE rmap_scan_buffer (char *base,yy_size_t size  );
YY_BUFFER_STATE rmap_scan_string (yyconst char *yy_str  );
YY_BUFFER_STATE rmap_scan_bytes (yyconst char *bytes,yy_size_t len  );

void *rmapalloc (yy_size_t  );
void *rmaprealloc (void *,yy_size_t  );
void rmapfree (void *  );

#define yy_new_buffer rmap_create_buffer

#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        rmapensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            rmap_create_buffer(rmapin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}

#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        rmapensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            rmap_create_buffer(rmapin,YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}

#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */

#define rmapwrap() 1
#define YY_SKIP_YYWRAP

typedef unsigned char YY_CHAR;

FILE *rmapin = (FILE *) 0, *rmapout = (FILE *) 0;

typedef int yy_state_type;

extern int rmaplineno;

int rmaplineno = 1;

extern char *rmaptext;
#define yytext_ptr rmaptext

static yy_state_type yy_get_previous_state (void );
static yy_state_type yy_try_NUL_trans (yy_state_type current_state  );
static int yy_get_next_buffer (void );
static void yy_fatal_error (yyconst char msg[]  ) __dead2;

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up rmaptext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	rmapleng = (size_t) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;

#define YY_NUM_RULES 35
#define YY_END_OF_BUFFER 36
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static yyconst flex_int16_t yy_accept[371] =
    {   0,
       34,   34,    0,    0,   36,   34,   32,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   35,   35,   34,   34,   33,   34,   32,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,    0,   32,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,

       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,    9,    9,   10,   10,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,

       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   11,   11,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   25,
       25,   26,   26,   34,   14,   14,   34,   34,   34,   34,
       34,   34,   34,   34,    6,    6,   34,   34,   34,   18,
       18,   34,   34,   22,   22,   34,   34,   34,   34,   34,
       34,   34,   34,   34,   34,    1,    1,    8,    8,   34,
        7,    7,   15,   15,   34,   34,   34,   34,   34,   34,
        2,    2,   34,   34,   34,   34,   34,   27,   27,   34,
       34,   34,   34,   34,   34,   34,   34,   34,   34,   34,

        5,    5,   34,   34,   24,   24,   28,   28,   34,   34,
       17,   17,   34,   34,   34,   20,   20,   34,   34,   34,
       34,    3,    3,   34,   34,   34,   34,   21,   21,   19,
       19,   34,   34,   34,   34,   34,   34,    4,    4,   34,
       34,   34,   12,   12,   13,   13,   34,   34,   34,   34,
       34,   31,   31,   29,   29,   34,   34,   34,   34,   30,
       30,   34,   34,   34,   16,   16,   34,   23,   23,    0
    } ;

static yyconst flex_int32_t yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    2,    1,    1,    4,    5,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    6,    7,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    8,    1,    9,   10,   11,   12,
       13,   14,   15,    1,    1,   16,   17,   18,   19,   20,
        1,   21,   22,   23,   24,   25,   26,   27,   28,   29,
        1,    1,    1,   30,   31,    1,   32,    1,   33,   34,

       35,   36,   37,   38,   39,    1,    1,   40,   41,   42,
       43,   44,    1,   45,   46,   47,   48,   49,   50,   51,
       52,   53,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static yyconst flex_int32_t yy_meta[54] =
    {   0,
        1,    1,    2,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1
    } ;

static yyconst flex_int16_t yy_base[406] =
    {   0,
        0,   30,   81,   82,  679,    0,  680,  675,    0,   72,
      102,   63,   76,   86,   76,   75,   90,   71,   80,   95,
       82,   83,  680,    4,    0,  674,  680,    5,    0,   95,
       98,   96,   90,  116,  120,  118,  119,  111,  124,  127,
      129,  128,  130,  137,  133,  136,  137,    6,  680,  131,
      135,  143,  135,  144,  138,  157,  161,  155,  163,  161,
      161,  175,  177,  173,  183,  176,  165,  166,  173,  176,
      184,  178,  190,  182,  184,  187,  184,  185,  194,  207,
      212,  216,  213,  223,  213,  214,  226,  227,  217,  221,
      233,  221,  226,  224,  229,  239,  645,  228,  228,  241,

      233,  234,  247,  253,  255,  255,  257,  673,  672,  259,
      263,  261,  261,  258,  269,  260,  272,  666,  280,  269,
      274,  274,  282,  291,  641,  640,  279,  280,  277,  668,
      667,  285,  295,  298,  311,  312,  637,  314,  636,  304,
      305,  325,  306,  315,  313,  316,  328,  317,  344,  319,
      315,  333,  329,    0,  664,    0,  663,  330,  334,  337,
      343,  363,  365,  365,  366,  662,  364,  360,  366,  361,
      358,  364,  632,  373,  381,  660,  659,  380,  658,  375,
      381,  382,  382,  398,  386,  657,  408,  409,  414,  656,
      408,  655,  401,  654,  415,  412,  412,  401,  418,  412,

      412,  653,  652,  423,  651,  415,  413,  650,  649,  419,
      648,  437,  647,  420,  416,  425,  646,  427,    0,  645,
      615,  643,  642,  430,  446,  446,  447,  449,  641,    0,
      640,    0,  639,  460,    0,  638,  448,  444,  637,  636,
      452,  635,  634,  460,    0,  633,  453,  466,  467,    0,
      632,  471,  472,    0,  631,  630,  464,  629,  472,  465,
      628,  627,  626,  470,  472,    0,  625,    0,  624,  623,
        0,  622,    0,  621,  471,  476,  476,  620,  477,  476,
        0,  619,  483,  618,  617,  491,  616,    0,  615,  614,
      492,  504,  613,  509,  612,  611,  610,  580,  510,    6,

        0,  608,  607,  499,    0,  606,    0,  605,  504,  604,
        0,  603,  502,  602,  601,    0,  600,  507,  511,  599,
      598,    0,  597,  504,  505,  596,  517,    0,  595,    0,
      594,  522,  520,  593,  592,  591,  590,    0,  589,  524,
      513,  513,    0,  588,    0,  587,  586,  585,  515,  584,
      510,    0,  583,    0,  582,  529,  581,  521,  580,    0,
      579,  534,  578,  577,    0,  576,  575,    0,  574,  680,
      569,  571,  567,  573,  566,  565,  562,  558,  557,  552,
      347,  346,  101,   96,   92,   88,   87,   86,   28,   27,
       26,   25,   24,   23,   22,   21,   20,   19,   18,   17,

       16,   15,   14,   13,    0
    } ;

static yyconst flex_int16_t yy_def[406] =
    {   0,
      371,  370,  372,  372,  370,  373,  370,  374,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  370,  370,  373,  374,  370,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  370,  370,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,

      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  375,
      376,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  375,  375,  376,  376,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  373,  373,  373,  373,  373,  373,  373,  373,  373,
      373,  377,  373,  373,  373,  373,  373,  373,  373,  373,

      373,  378,  379,  373,  380,  373,  373,  373,  373,  373,
      373,  373,  381,  373,  373,  373,  382,  373,  377,  377,
      373,  383,  373,  373,  373,  373,  373,  373,  373,  378,
      378,  379,  379,  373,  380,  380,  373,  373,  384,  385,
      373,  386,  387,  373,  381,  381,  373,  373,  373,  382,
      382,  373,  373,  383,  383,  388,  373,  373,  373,  373,
      373,  389,  373,  373,  373,  384,  384,  385,  385,  373,
      386,  386,  387,  387,  373,  373,  373,  373,  373,  373,
      388,  388,  373,  390,  373,  373,  391,  389,  389,  392,
      373,  373,  393,  373,  373,  373,  394,  373,  373,  373,

      390,  390,  395,  373,  391,  391,  392,  392,  373,  373,
      393,  393,  373,  396,  397,  394,  394,  373,  373,  373,
      373,  395,  395,  373,  373,  398,  373,  396,  396,  397,
      397,  373,  373,  399,  400,  373,  373,  398,  398,  373,
      373,  373,  399,  399,  400,  400,  401,  402,  373,  373,
      373,  401,  401,  402,  402,  373,  403,  373,  373,  403,
      403,  373,  404,  373,  404,  404,  405,  405,  405,    0,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,

      370,  370,  370,  370,  370
    } ;

static yyconst flex_int16_t yy_nxt[734] =
    {   0,
      368,   28,    7,    8,   29,   48,   28,   48,   49,   29,
       49,  320,  321,  365,  360,  354,  352,  345,  343,  338,
      330,  328,  322,  316,  311,  307,  305,  301,  288,    9,
        6,    6,    7,    8,    6,    6,    6,    6,   10,   11,
       12,   13,    6,    6,    6,   14,   15,    6,   16,    6,
       17,   18,   19,    6,    6,   20,   21,   22,    6,    9,
        6,    6,   10,   11,   12,   13,    6,    6,    6,   14,
       15,    6,   16,    6,   17,   18,   19,    6,    6,   20,
       21,   22,    6,    7,    7,   30,  281,  273,  271,   35,
       36,   37,  268,   38,   39,   41,  266,   42,   43,   40,

       44,  254,   45,   46,   47,   50,   51,   52,   53,   30,
       24,   24,   31,   35,   36,   37,   32,   38,   39,   41,
       33,   42,   43,   40,   44,   34,   45,   46,   47,   50,
       51,   52,   53,   54,   55,   57,   31,   58,   59,   56,
       32,   60,   61,   62,   33,   63,   64,   65,   66,   34,
       67,   68,   69,   70,   71,   72,   73,   54,   55,   57,
       74,   58,   59,   56,   75,   60,   61,   62,   76,   63,
       64,   65,   66,   77,   67,   68,   69,   70,   71,   72,
       73,   78,   79,   80,   74,   81,   83,   82,   75,   84,
       85,   86,   76,   87,   88,   89,   90,   77,   91,   92,

       93,   96,   97,   94,   98,   78,   79,   80,   99,   81,
       83,   82,   95,   84,   85,   86,  100,   87,   88,   89,
       90,  101,   91,   92,   93,   96,   97,   94,   98,  102,
      103,  104,   99,  105,  106,  107,  108,  109,  110,  111,
      100,  113,  112,  114,  115,  101,  116,  117,  118,  120,
      121,  122,  123,  102,  103,  104,  124,  105,  106,  107,
      108,  109,  110,  111,  125,  113,  112,  114,  115,  126,
      116,  117,  118,  120,  121,  122,  123,  127,  128,  129,
      124,  132,  133,  134,  135,  136,  137,  138,  125,  139,
      141,  143,  144,  126,  146,  145,  142,  147,  148,  151,

      152,  127,  128,  129,  153,  132,  133,  134,  135,  136,
      137,  138,  158,  139,  141,  143,  144,  159,  146,  145,
      142,  147,  148,  151,  152,  160,  161,  162,  153,  164,
      166,  167,  168,  169,  170,  171,  158,  172,  173,  174,
      178,  159,  179,  180,  181,  182,  250,  245,  183,  160,
      161,  162,  184,  164,  166,  167,  168,  169,  170,  171,
      175,  172,  173,  174,  178,  185,  179,  180,  181,  182,
      176,  177,  183,  186,  187,  190,  184,  191,  193,  194,
      188,  195,  189,  196,  175,  197,  198,  200,  201,  185,
      204,  208,  209,  206,  176,  177,  207,  186,  187,  190,

      210,  191,  193,  194,  188,  195,  189,  196,  211,  197,
      198,  200,  201,  212,  204,  208,  209,  206,  214,  215,
      207,  216,  218,  221,  210,  223,  224,  225,  226,  227,
      228,  229,  211,  234,  237,  238,  241,  212,  243,  247,
      248,  249,  214,  215,  252,  216,  218,  221,  257,  223,
      224,  225,  226,  227,  228,  229,  258,  234,  237,  238,
      241,  259,  260,  247,  248,  249,  261,  244,  252,  263,
      264,  265,  257,  270,  275,  276,  277,  278,  279,  280,
      258,  283,  285,  286,  291,  259,  260,  292,  294,  295,
      261,  296,  298,  263,  264,  265,  299,  270,  275,  276,

      277,  278,  279,  280,  300,  283,  285,  286,  291,  304,
      309,  292,  294,  295,  310,  296,  298,  313,  319,  324,
      299,  325,  327,  332,  333,  336,  337,  340,  300,  341,
      342,  349,  350,  304,  309,  351,  356,  358,  310,  359,
      362,  313,  319,  324,  364,  325,  327,  332,  333,  336,
      337,  340,  235,  341,  342,  349,  350,  232,  230,  351,
      356,  358,  219,  359,  362,  156,  154,   25,  364,    6,
        6,   23,   23,   26,   26,  369,  369,  366,  367,  366,
      361,  363,  361,  355,  353,  357,  355,  353,  346,  344,
      339,  348,  347,  346,  344,  331,  329,  339,  323,  335,

      334,  317,  331,  329,  312,  326,  308,  306,  323,  302,
      318,  317,  315,  314,  312,  308,  289,  306,  303,  302,
      282,  297,  274,  272,  293,  269,  267,  290,  289,  287,
      284,  282,  255,  251,  246,  274,  272,  269,  267,  236,
      233,  231,  262,  256,  255,  253,  220,  251,  246,  242,
      240,  239,  236,  233,  231,  222,  220,  217,  213,  205,
      203,  202,  199,  192,  157,  155,  165,  163,  157,  155,
      150,  149,  140,  131,  130,  119,   27,   27,  370,    5,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,

      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370
    } ;

static yyconst flex_int16_t yy_chk[734] =
    {   0,
      405,    9,    1,    1,    9,   24,   28,   48,   24,   28,
       48,  300,  300,  404,  403,  402,  401,  400,  399,  398,
      397,  396,  395,  394,  393,  392,  391,  390,  389,    1,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    2,    2,    2,    2,    2,    2,    2,
        2,    2,    2,    3,    4,   10,  388,  387,  386,   12,
       13,   13,  385,   14,   15,   16,  384,   17,   18,   15,

       19,  383,   20,   21,   22,   30,   31,   32,   33,   10,
        3,    4,   11,   12,   13,   13,   11,   14,   15,   16,
       11,   17,   18,   15,   19,   11,   20,   21,   22,   30,
       31,   32,   33,   34,   35,   36,   11,   37,   38,   35,
       11,   39,   40,   41,   11,   42,   43,   44,   45,   11,
       46,   47,   50,   51,   52,   53,   54,   34,   35,   36,
       55,   37,   38,   35,   56,   39,   40,   41,   57,   42,
       43,   44,   45,   58,   46,   47,   50,   51,   52,   53,
       54,   59,   60,   61,   55,   62,   63,   62,   56,   64,
       65,   66,   57,   67,   68,   69,   70,   58,   71,   72,

       73,   75,   76,   74,   77,   59,   60,   61,   78,   62,
       63,   62,   74,   64,   65,   66,   79,   67,   68,   69,
       70,   80,   71,   72,   73,   75,   76,   74,   77,   81,
       82,   83,   78,   84,   85,   86,   87,   88,   89,   90,
       79,   91,   90,   92,   93,   80,   94,   95,   96,   98,
       99,  100,  101,   81,   82,   83,  102,   84,   85,   86,
       87,   88,   89,   90,  103,   91,   90,   92,   93,  104,
       94,   95,   96,   98,   99,  100,  101,  105,  106,  107,
      102,  110,  111,  112,  113,  114,  115,  116,  103,  117,
      119,  120,  121,  104,  122,  121,  119,  123,  124,  127,

      128,  105,  106,  107,  129,  110,  111,  112,  113,  114,
      115,  116,  132,  117,  119,  120,  121,  133,  122,  121,
      119,  123,  124,  127,  128,  134,  135,  136,  129,  138,
      140,  141,  142,  143,  144,  145,  132,  146,  147,  148,
      150,  133,  151,  152,  153,  158,  382,  381,  159,  134,
      135,  136,  160,  138,  140,  141,  142,  143,  144,  145,
      149,  146,  147,  148,  150,  161,  151,  152,  153,  158,
      149,  149,  159,  162,  163,  164,  160,  165,  167,  168,
      163,  169,  163,  170,  149,  171,  172,  174,  175,  161,
      178,  181,  182,  180,  149,  149,  180,  162,  163,  164,

      183,  165,  167,  168,  163,  169,  163,  170,  184,  171,
      172,  174,  175,  185,  178,  181,  182,  180,  187,  188,
      180,  189,  191,  193,  183,  195,  196,  197,  198,  199,
      200,  201,  184,  204,  206,  207,  210,  185,  212,  214,
      215,  216,  187,  188,  218,  189,  191,  193,  224,  195,
      196,  197,  198,  199,  200,  201,  225,  204,  206,  207,
      210,  226,  227,  214,  215,  216,  228,  212,  218,  234,
      237,  238,  224,  241,  244,  247,  248,  249,  252,  253,
      225,  257,  259,  260,  264,  226,  227,  265,  275,  276,
      228,  277,  279,  234,  237,  238,  280,  241,  244,  247,

      248,  249,  252,  253,  283,  257,  259,  260,  264,  286,
      291,  265,  275,  276,  292,  277,  279,  294,  299,  304,
      280,  309,  313,  318,  319,  324,  325,  327,  283,  332,
      333,  340,  341,  286,  291,  342,  349,  351,  292,  356,
      358,  294,  299,  304,  362,  309,  313,  318,  319,  324,
      325,  327,  380,  332,  333,  340,  341,  379,  378,  342,
      349,  351,  377,  356,  358,  376,  375,  373,  362,  371,
      371,  372,  372,  374,  374,  369,  367,  366,  364,  363,
      361,  359,  357,  355,  353,  350,  348,  347,  346,  344,
      339,  337,  336,  335,  334,  331,  329,  326,  323,  321,

      320,  317,  315,  314,  312,  310,  308,  306,  303,  302,
      298,  297,  296,  295,  293,  290,  289,  287,  285,  284,
      282,  278,  274,  272,  270,  269,  267,  263,  262,  261,
      258,  256,  255,  251,  246,  243,  242,  240,  239,  236,
      233,  231,  229,  223,  222,  221,  220,  217,  213,  211,
      209,  208,  205,  203,  202,  194,  192,  190,  186,  179,
      177,  176,  173,  166,  157,  155,  139,  137,  131,  130,
      126,  125,  118,  109,  108,   97,   26,    8,    5,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,

      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370,  370,  370,  370,  370,  370,  370,  370,
      370,  370,  370
    } ;

static yy_state_type yy_last_accepting_state;
static char *yy_last_accepting_cpos;

extern int rmap_flex_debug;
int rmap_flex_debug = 0;

/* The intent behind this definition is that it'll catch
 * any uses of REJECT which flex missed.
 */
#define REJECT reject_used_but_not_detected
#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *rmaptext;
#line 1 "reader.l"
#line 2 "reader.l"
/*
 * static char *reader_l =
 *   "$Id$";
 */

/*
    CrossFire, A Multiplayer game for X-windows

    Copyright (C) 1994 Mark Wedel
    Copyright (C) 1992 Frank Tore Johansen

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

    The author can be reached via e-mail to mark@pyramid.com
*/

#include <global.h>
#include <loader.h>
#include <newserver.h>
#include <random_map.h>

#define YY_DECL int rmap_lex_read(RMParms *RP)

static char *rmap_yval(void);
static int rmap_lex_read(RMParms *RP);

static int rmap_lex_error;

#define IVAL atoi(rmap_yval())
#define FVAL atof(rmap_yval())

/**
 * Error handler.
 *
 * @param s
 * lex-generated error message.
 */
static int yyerror(const char *s)
{
    LOG(llevError, "%s: %s\n", s, rmaptext);
    return -1;
}


/* Don't have to link with -lfl with this */
/* those functions are unused, not sure of compatibility with Flex versions. */
#define YY_NO_INPUT 1
#line 836 "reader.c"

#define INITIAL 0
#define MESSAGE 1

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals (void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int rmaplex_destroy (void );

int rmapget_debug (void );

void rmapset_debug (int debug_flag  );

YY_EXTRA_TYPE rmapget_extra (void );

void rmapset_extra (YY_EXTRA_TYPE user_defined  );

FILE *rmapget_in (void );

void rmapset_in  (FILE * in_str  );

FILE *rmapget_out (void );

void rmapset_out  (FILE * out_str  );

yy_size_t rmapget_leng (void );

char *rmapget_text (void );

int rmapget_lineno (void );

void rmapset_lineno (int line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int rmapwrap (void );
#else
extern int rmapwrap (void );
#endif
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy (char *,yyconst char *,int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * );
#endif

#ifndef YY_NO_INPUT

#ifdef __cplusplus
static int yyinput (void );
#else
static int input (void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#define YY_READ_BUF_SIZE 8192
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( rmaptext, rmapleng, 1, rmapout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		size_t n; \
		for ( n = 0; n < max_size && \
			     (c = getc( rmapin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( rmapin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = fread(buf, 1, max_size, rmapin))==0 && ferror(rmapin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(rmapin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int rmaplex (void);

#define YY_DECL int rmaplex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after rmaptext and rmapleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK break;
#endif

#define YY_RULE_SETUP \
	if ( rmapleng > 0 ) \
		YY_CURRENT_BUFFER_LVALUE->yy_at_bol = \
				(rmaptext[rmapleng - 1] == '\n'); \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
#line 72 "reader.l"



/* Declare some local variables */

    rmap_lex_error = 0;



#line 1030 "reader.c"

	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! rmapin )
			rmapin = stdin;

		if ( ! rmapout )
			rmapout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			rmapensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				rmap_create_buffer(rmapin,YY_BUF_SIZE );
		}

		rmap_load_buffer_state( );
		}

	while ( 1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of rmaptext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);
		yy_current_state += YY_AT_BOL();
yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			if ( yy_accept[yy_current_state] )
				{
				(yy_last_accepting_state) = yy_current_state;
				(yy_last_accepting_cpos) = yy_cp;
				}
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 371 )
					yy_c = yy_meta[(unsigned int) yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 680 );

yy_find_action:
		yy_act = yy_accept[yy_current_state];
		if ( yy_act == 0 )
			{ /* have to back up */
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			yy_act = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
			case 0: /* must back up */
			/* undo the effects of YY_DO_BEFORE_ACTION */
			*yy_cp = (yy_hold_char);
			yy_cp = (yy_last_accepting_cpos);
			yy_current_state = (yy_last_accepting_state);
			goto yy_find_action;

case 1:
YY_RULE_SETUP
#line 81 "reader.l"
strncpy(RP->wallstyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 2:
YY_RULE_SETUP
#line 82 "reader.l"
strncpy(RP->floorstyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 83 "reader.l"
strncpy(RP->monsterstyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 84 "reader.l"
strncpy(RP->treasurestyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 85 "reader.l"
strncpy(RP->layoutstyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 86 "reader.l"
strncpy(RP->doorstyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 87 "reader.l"
strncpy(RP->decorstyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 88 "reader.l"
strncpy(RP->cheststyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 9:
YY_RULE_SETUP
#line 89 "reader.l"
RP->Xsize = IVAL;
	YY_BREAK
case 10:
YY_RULE_SETUP
#line 90 "reader.l"
RP->Ysize = IVAL;
	YY_BREAK
case 11:
YY_RULE_SETUP
#line 91 "reader.l"
RP->expand2x = IVAL;
	YY_BREAK
case 12:
YY_RULE_SETUP
#line 92 "reader.l"
RP->layoutoptions1 = IVAL;
	YY_BREAK
case 13:
YY_RULE_SETUP
#line 93 "reader.l"
RP->layoutoptions2 = IVAL;
	YY_BREAK
case 14:
YY_RULE_SETUP
#line 94 "reader.l"
RP->symmetry = IVAL;
	YY_BREAK
case 15:
YY_RULE_SETUP
#line 95 "reader.l"
RP->difficulty = IVAL;
	YY_BREAK
case 16:
YY_RULE_SETUP
#line 96 "reader.l"
RP->difficulty_increase = FVAL;
	YY_BREAK
case 17:
YY_RULE_SETUP
#line 97 "reader.l"
RP->decoroptions = IVAL;
	YY_BREAK
case 18:
YY_RULE_SETUP
#line 98 "reader.l"
strncpy(RP->exitstyle, rmap_yval(), RM_SIZE);
	YY_BREAK
case 19:
YY_RULE_SETUP
#line 99 "reader.l"
RP->dungeon_level = IVAL;
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 100 "reader.l"
strncpy(RP->dungeon_name, rmap_yval(), RM_SIZE);
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 101 "reader.l"
RP->dungeon_depth = IVAL;
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 102 "reader.l"
strncpy(RP->final_map, rmap_yval(), RM_SIZE);
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 103 "reader.l"
strncpy(RP->final_exit_archetype, rmap_yval(), RM_SIZE);
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 104 "reader.l"
RP-> orientation = IVAL;
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 105 "reader.l"
RP->origin_x = IVAL;
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 106 "reader.l"
RP-> origin_y = IVAL;
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 107 "reader.l"
strncpy(RP->origin_map, rmap_yval(), RM_SIZE);
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 108 "reader.l"
RP->random_seed = IVAL;
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 109 "reader.l"
RP->treasureoptions = IVAL;
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 110 "reader.l"
strncpy(RP->exit_on_final_map, rmap_yval(), RM_SIZE);
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 111 "reader.l"
RP->multiple_floors = IVAL;
	YY_BREAK
case 32:
/* rule 32 can match eol */
YY_RULE_SETUP
#line 113 "reader.l"
{/* ignore empty lines, newlines we don't do above */}
	YY_BREAK
case 33:
/* rule 33 can match eol */
YY_RULE_SETUP
#line 114 "reader.l"
{ }
	YY_BREAK
case YY_STATE_EOF(INITIAL):
case YY_STATE_EOF(MESSAGE):
#line 116 "reader.l"
{/* If we got an error, return the error.  Otherwise, return that we got EOF */
                             if (rmap_lex_error != 0)
                                 return rmap_lex_error;
                             else
                                 return LL_EOF;
                         }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 122 "reader.l"
{
                             yyerror("Unrecognized string");
                             rmap_lex_error= -1;
                         }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 126 "reader.l"
ECHO;
	YY_BREAK
#line 1304 "reader.c"

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed rmapin at a new source and called
			 * rmaplex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = rmapin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( rmapwrap( ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * rmaptext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
} /* end of rmaplex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr)) - 1;

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			yy_size_t num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			/* just a shorter name for the current buffer */
			YY_BUFFER_STATE b = YY_CURRENT_BUFFER_LVALUE;

			int yy_c_buf_p_offset =
				(int) ((yy_c_buf_p) - b->yy_ch_buf);

			if ( b->yy_is_our_buffer )
				{
				yy_size_t new_size = b->yy_buf_size * 2;

				if ( new_size <= 0 )
					b->yy_buf_size += b->yy_buf_size / 8;
				else
					b->yy_buf_size *= 2;

				b->yy_ch_buf = (char *)
					/* Include room in for 2 EOB chars. */
					rmaprealloc((void *) b->yy_ch_buf,b->yy_buf_size + 2  );
				}
			else
				/* Can't grow it, we don't own it. */
				b->yy_ch_buf = 0;

			if ( ! b->yy_ch_buf )
				YY_FATAL_ERROR(
				"fatal error - scanner input buffer overflow" );

			(yy_c_buf_p) = &b->yy_ch_buf[yy_c_buf_p_offset];

			num_to_read = YY_CURRENT_BUFFER_LVALUE->yy_buf_size -
						number_to_move - 1;

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			rmaprestart(rmapin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if ((yy_size_t) ((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		yy_size_t new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) rmaprealloc((void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf,new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);
	yy_current_state += YY_AT_BOL();

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		if ( yy_accept[yy_current_state] )
			{
			(yy_last_accepting_state) = yy_current_state;
			(yy_last_accepting_cpos) = yy_cp;
			}
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 371 )
				yy_c = yy_meta[(unsigned int) yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    	char *yy_cp = (yy_c_buf_p);

	YY_CHAR yy_c = 1;
	if ( yy_accept[yy_current_state] )
		{
		(yy_last_accepting_state) = yy_current_state;
		(yy_last_accepting_cpos) = yy_cp;
		}
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 371 )
			yy_c = yy_meta[(unsigned int) yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + (unsigned int) yy_c];
	yy_is_jam = (yy_current_state == 370);

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			yy_size_t offset = (yy_c_buf_p) - (yytext_ptr);
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					rmaprestart(rmapin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( rmapwrap( ) )
						return EOF;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve rmaptext */
	(yy_hold_char) = *++(yy_c_buf_p);

	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = (c == '\n');

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void rmaprestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        rmapensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            rmap_create_buffer(rmapin,YY_BUF_SIZE );
	}

	rmap_init_buffer(YY_CURRENT_BUFFER,input_file );
	rmap_load_buffer_state( );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void rmap_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		rmappop_buffer_state();
	 *		rmappush_buffer_state(new_buffer);
     */
	rmapensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	rmap_load_buffer_state( );

	/* We don't actually know whether we did this switch during
	 * EOF (rmapwrap()) processing, but the only time this flag
	 * is looked at is after rmapwrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void rmap_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	rmapin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE rmap_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) rmapalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in rmap_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) rmapalloc(b->yy_buf_size + 2  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in rmap_create_buffer()" );

	b->yy_is_our_buffer = 1;

	rmap_init_buffer(b,file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with rmap_create_buffer()
 * 
 */
    void rmap_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		rmapfree((void *) b->yy_ch_buf  );

	rmapfree((void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a rmaprestart() or at EOF.
 */
    static void rmap_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	rmap_flush_buffer(b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then rmap_init_buffer was _probably_
     * called from rmaprestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void rmap_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		rmap_load_buffer_state( );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void rmappush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	rmapensure_buffer_stack();

	/* This block is copied from rmap_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from rmap_switch_to_buffer. */
	rmap_load_buffer_state( );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void rmappop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	rmap_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		rmap_load_buffer_state( );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void rmapensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
		num_to_alloc = 1;
		(yy_buffer_stack) = (struct yy_buffer_state**)rmapalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in rmapensure_buffer_stack()" );
								  
		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));
				
		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		int grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)rmaprealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in rmapensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object. 
 */
YY_BUFFER_STATE rmap_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return 0;

	b = (YY_BUFFER_STATE) rmapalloc(sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in rmap_scan_buffer()" );

	b->yy_buf_size = size - 2;	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = 0;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	rmap_switch_to_buffer(b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to rmaplex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       rmap_scan_bytes() instead.
 */
YY_BUFFER_STATE rmap_scan_string (yyconst char * yystr )
{
    
	return rmap_scan_bytes(yystr,strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to rmaplex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE rmap_scan_bytes  (yyconst char * yybytes, yy_size_t  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	yy_size_t i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = _yybytes_len + 2;
	buf = (char *) rmapalloc(n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in rmap_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = rmap_scan_buffer(buf,n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in rmap_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yy_fatal_error (yyconst char* msg )
{
    	(void) fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up rmaptext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		rmaptext[rmapleng] = (yy_hold_char); \
		(yy_c_buf_p) = rmaptext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		rmapleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int rmapget_lineno  (void)
{
        
    return rmaplineno;
}

/** Get the input stream.
 * 
 */
FILE *rmapget_in  (void)
{
        return rmapin;
}

/** Get the output stream.
 * 
 */
FILE *rmapget_out  (void)
{
        return rmapout;
}

/** Get the length of the current token.
 * 
 */
yy_size_t rmapget_leng  (void)
{
        return rmapleng;
}

/** Get the current token.
 * 
 */

char *rmapget_text  (void)
{
        return rmaptext;
}

/** Set the current line number.
 * @param line_number
 * 
 */
void rmapset_lineno (int  line_number )
{
    
    rmaplineno = line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param in_str A readable stream.
 * 
 * @see rmap_switch_to_buffer
 */
void rmapset_in (FILE *  in_str )
{
        rmapin = in_str ;
}

void rmapset_out (FILE *  out_str )
{
        rmapout = out_str ;
}

int rmapget_debug  (void)
{
        return rmap_flex_debug;
}

void rmapset_debug (int  bdebug )
{
        rmap_flex_debug = bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from rmaplex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = 0;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = (char *) 0;
    (yy_init) = 0;
    (yy_start) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    rmapin = stdin;
    rmapout = stdout;
#else
    rmapin = (FILE *) 0;
    rmapout = (FILE *) 0;
#endif

    /* For future reference: Set errno on error, since we are called by
     * rmaplex_init()
     */
    return 0;
}

/* rmaplex_destroy is for both reentrant and non-reentrant scanners. */
int rmaplex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		rmap_delete_buffer(YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		rmappop_buffer_state();
	}

	/* Destroy the stack itself. */
	rmapfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * rmaplex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, yyconst char * s2, int n )
{
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (yyconst char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *rmapalloc (yy_size_t  size )
{
	return (void *) malloc( size );
}

void *rmaprealloc  (void * ptr, yy_size_t  size )
{
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return (void *) realloc( (char *) ptr, size );
}

void rmapfree (void * ptr )
{
	free( (char *) ptr );	/* see rmaprealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 126 "reader.l"



/* Our save file syntax is very simple, so we can use a very simple
 * processing mechanism here instead using something like bison
 * This skips over the space and returns the value, or "" if no value
 * is found.
 */
static char *rmap_yval(void) {
    static char em[] = "";
    char *cp;

    cp = strchr(rmaptext, ' ');
    if (cp)
        return cp+1;
    else
        return em;
}

int load_parameters(FILE *fp, int bufstate, RMParms *RP) {
    int retval;
    char inbuf[MAX_BUF];

    if (bufstate == LO_NEWFILE || bufstate == LO_NOREAD) {
        rmap_delete_buffer(YY_CURRENT_BUFFER);
        rmap_switch_to_buffer(rmap_create_buffer(fp,YY_BUF_SIZE));
        if (bufstate == LO_NOREAD)
            return LL_NORMAL;
    }
    if (bufstate == LO_LINEMODE) {
        YY_BUFFER_STATE yybufstate;
        while (fgets(inbuf, MAX_BUF-3, fp)) {
            yybufstate = rmap_scan_string(inbuf);
            retval = rmap_lex_read(RP);
            rmap_delete_buffer(yybufstate);
            if (retval == LL_NORMAL)
                return retval;
        }
        return LL_EOF;
    }

    retval = rmap_lex_read(RP);
/*    LOG(llevDebug, " load completed, object=%s\n", op->name);*/
    return retval;
}


/* This takes a buffer, scans it for variables, and sets those variables
 * as appropriate in op.
 *
 * This function appears to be used in only 2 places - in crossedit to
 * override values and in c_wiz to mutate values.
 */
int set_random_map_variable(RMParms *rp, const char *buf) {
    YY_BUFFER_STATE yybufstate;
    int retval;

    yybufstate = rmap_scan_string(buf);
    retval = rmap_lex_read(rp);
    rmap_delete_buffer(yybufstate);
    return retval;
}

